<?php
$lang['detected'] = 'Detectado';
$lang['docroot_leaveblank'] = 'Deixe em branco para usar a predefini&ccedil;&atilde;o do sistema';
$lang['test_xmlreader_class'] = 'A verificar se a classe XMLReader existe';
$lang['test_xmlreader_failed'] = 'A classe XmlReader n&atilde;o est&aacute; habilitada na sua instala&ccedil;&atilde;o de php. Pode utilizar o sistema, mas n&atilde;o ser&aacute; poss&iacute;vel usar nenhuma das fun&ccedil;&otilde;es de instala&ccedil;&atilde;o remota de m&oacute;dulos.';
$lang['test_check_xml_failed'] = 'O suporte XML n&atilde;o foi compilado na sua instala&ccedil;&atilde;o de php. Pode utilizar o sistema, mas n&atilde;o ser&aacute; poss&iacute;vel usar nenhuma das fun&ccedil;&otilde;es de instala&ccedil;&atilde;o remota de m&oacute;dulos.';
$lang['installed_module'] = 'M&oacute;dulo Instalado';
$lang['automatedtask_success'] = 'Tarefa Automatizada Conclu&iacute;da Com Sucesso';
$lang['ip_addr'] = 'Endere&ccedil;o IP';
$lang['install_admin_pwsalt_note'] = 'If you choose to enable password salts, there is absolutely no way to reset lost admin passwords, other than through the lost password functionality.   It is critical that you associate an email address with each admin account';
$lang['admin_salt'] = 'Salt Admin Passwords';
$lang['setup_flat_urls'] = 'Flat URLs are setup';
$lang['install_timezone'] = 'Some servers running PHP 5.3 do not have the timezone set correctly. Please select the appropriate timezone from the list below before proceeding. If this is not necessary on your server, you may select &quot;None&quot;. <strong>Note:</strong> Please select your servers timezone, this is not a display setting, but is used in arithmetic related to dates.  This setting can be changed after installation by modifying the config.php file.';
$lang['timezone'] = 'Timezone';
$lang['none'] = 'None';
$lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
$lang['test_estrict_failed'] = 'E_STRICT is enabled';
$lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
$lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
$lang['test_edeprecated_failed'] = 'E_DEPRECATED is enabled';
$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see a lot of warning messages that could effect the display and functionality';
$lang['invalidemail'] = 'The email address entered is invalid';
$lang['empty_query'] = 'Empty query?? %s';
$lang['no_db_driver'] = 'No compatible database drivers found';
$lang['test_check_output_buffering'] = 'Checking output buffering';
$lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
$lang['phpinfo'] = 'Display PHP Information';
$lang['mod_security'] = 'Apache Mod Security';
$lang['test_check_tempnam'] = 'Checking for tempnam Function';
$lang['test_check_db_drivers'] = 'DB drivers';
$lang['test_check_db_drivers_failed'] = 'No DB drivers found';
$lang['test_check_register_globals'] = 'Checking PHP register globals';
$lang['test_check_register_globals_failed'] = 'PHP register globals is active. For security reasons, this should be disabled.';
$lang['test_check_disable_functions'] = 'Checking PHP disable functions';
$lang['test_check_disable_functions_failed'] = 'Warning: this is a list of functions disabled on your server.';
$lang['install_admin_db_port'] = 'Database port';
$lang['install_admin_db_port_info'] = 'If you don&#039;t know, leave this blank to use default settings.';
$lang['install_admin_db_socket'] = 'Database socket';
$lang['install_admin_db_socket_info'] = 'NOT SUPPORTED.';
$lang['install_admin_frontendlang'] = 'Default language for the frontend. This adjusts the locale used for various default date handling functions, etc.';
$lang['install_default_encoding'] = 'In almost all cases, default_encoding should be utf-8. If you&#039;d like this to be different, change this but keep in mind, however, that the languages translations are all in utf-8';
$lang['installer_done'] = '[completo]';
$lang['installer_failed'] = '[falhou]';
$lang['create_permission'] = 'Criar permiss&otilde;es ...';
$lang['add_column_sql'] = 'Adding column to %s table ...';
$lang['update_table_sql'] = 'Actualizar tabela %s ...';
$lang['installing_module'] = 'Installing %s module ...';
$lang['updating_schema_version'] = 'Updating schema version %s ...';
$lang['upgrade_config'] = 'Upgrading config.php';
$lang['upgrade_config_info'] = 'config upgrade';
$lang['upgrade_failed_again'] = 'One or more upgrades have failed. Please correct the problem and click the button below to recheck.';
$lang['upgrade_cache_dirs'] = 'Cleaning cache dirs';
$lang['cannot_clean_cache_dirs'] = 'Cannot cleaning cache dirs!';
$lang['upgrade_schema'] = 'Upgrade schema';
$lang['need_upgrade_schema'] = 'CMS is in need of an upgrade.<br />You are now running schema version %s and you need to be upgraded to version %s';
$lang['schema_ok'] = 'Now the CMS database is up to date using schema version %s';
$lang['noneed_upgrade_schema'] = 'The CMS database is up to date using schema version %s';
$lang['upgrade_modules'] = 'Upgrade modules';
$lang['noneed_upgrade_modules'] = 'The core modules are up to date';
$lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of &quot;%s&quot; module from %s to %s ...';
$lang['upgrade_event_module_from_to'] = 'Upgrading Events of &quot;%s&quot; module from %s to %s ...';
$lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a &quot;Site Down for Maintainence&quot; message on your site';
$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it&#039;s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as &quot;Needs Upgrade&quot;';
$lang['upgrade_complete'] = 'Upgrade process complete';
$lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
$lang['here'] = 'aqui';
$lang['go_to_admin'] = 'go to the Admin Panel';
$lang['errorfilenot'] = 'File not found!';
$lang['errorfilenotwritable'] = 'File not writable!';
$lang['nofiles'] = 'This resource not exist!';
$lang['is_directory'] = 'This resource is a directory!';
$lang['is_readable_false'] = 'This resource is not readable!';
$lang['checksum_match'] = 'Checksum match!';
$lang['checksum_not_match'] = 'Checksum not match!';
$lang['not_checksum'] = 'No checksum retrieve!';
$lang['format_datetime'] = '%c';
$lang['upload_err_ini_size'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini!';
$lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
$lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
$lang['upload_err_no_file'] = 'No file was uploaded.';
$lang['upload_err_no_tmp_dir'] = 'Missing a temporary folder.';
$lang['upload_err_cant_write'] = 'Failed to write file to disk.';
$lang['upload_err_extension'] = 'File upload stopped by extension.';
$lang['upload_err_empty'] = 'File has size zero';
$lang['upload_err_unknown'] = 'Unknown file upload problem.';
$lang['function_file_uploads_off'] = 'file_uploads is off in your php configuration!';
$lang['upload_file_no_readable'] = 'Uploaded file is not readable!';
$lang['upload_file_multiple'] = 'Multiple file uploads are not allowed!';
$lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
$lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. You can to have problems in save templates.';
$lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
$lang['test_check_magic_quotes_runtime_failed'] = 'When magic_quotes are on, most functions that return data from any sort of external source including databases and text files will have quotes escaped with a backslash. You can to have problems.';
$lang['install_admin_checksum'] = 'Check your installation';
$lang['upgrade_admin_checksum'] = 'Check your system upgrading';
$lang['checksum'] = 'Checksum test';
$lang['checksum_file'] = 'Checksum file';
$lang['install_test_checksum'] = 'You can validate the integrity of your CMS files by comparing against original CMS checksum. It can assist in finding problems with uploads.';
$lang['checksum_passed'] = 'All checksums match!';
$lang['checksum_failed'] = 'Checksum match with errors. Look at the help for more information';
$lang['test_check_open_basedir'] = 'Verificar PHP Open Basedir';
$lang['test_check_open_basedir_failed'] = 'As restri&ccedil;&otilde;es Open basedir est&atilde;o activas. Pode ter algumas dificuldades em alguns addons com esta restri&ccedil;&atilde;o.';
$lang['unlimited'] = 'Ilimitado';
$lang['test_open_basedir_session_save_path'] = 'Restri&ccedil;&otilde;es de Open basedir est&atilde;o, aparentemente, em efeito. Se tem problemas de Sess&atilde;o (SESSION) e a configura&ccedil;&atilde;o ini_set funciona, pode tentar habilitar as sess&otilde;es com cookies adicionando: ini_set(&#039;session.use_only_cookies&#039;, 1); ao inicio do seu config.php.';
$lang['install_warn_db_createtables'] = 'Normalmente, este campo deve estar sempre seleccionado. Tenha cuidado ao desactivar este recurso';
$lang['install_admin_tablesnotcreated'] = 'Processo completo. O processo de instala&ccedil;&atilde;o est&aacute; conclu&iacute;do, com a sua auroriza&ccedil;&atilde;o os dados nas tabelas n&atilde;o foram criados. No entanto, o arquivo de configura&ccedil;&atilde;o foi recriado e todos os testes de pr&eacute;-instala&ccedil;&atilde;o foram aprovados. Muito obrigado, e aqui est&aacute; o seu';
$lang['info_create_dir_and_file'] = 'O propriet&aacute;rio do Processo HTTP n&atilde;o pode criar um arquivo dentro de um direct&oacute;rio que &eacute; propriet&aacute;rio. Isso provavelmente significa que modo seguro est&aacute; activado, de alguma forma. Muitas fun&ccedil;&otilde;es dentro CMS  n&atilde;o ir&aacute; funcionar adequadamente sem essa capacidade. N&atilde;o &eacute; poss&iacute;vel continuar.';
$lang['test_create_dir_and_file'] = 'Verificar se o processo httpd pode criar um arquivo dentro de um direct&oacute;rio criado.';
$lang['cms_site'] = 'CMS Site ';
$lang['or_greater'] = 'Ou superior';
$lang['sitename'] = 'Nome do Site';
$lang['warning_safe_mode'] = '<strong>AVISO: </strong> PHP safe mode est&aacute; activo. Isto ir&aacute; causar dificuldade nos arquivos enviados atrav&eacute;s da interface web browser, incluindo imagens, tema e m&oacute;dulo pacotes XML.';
$lang['test'] = 'Teste';
$lang['results'] = 'Resultados';
$lang['untested'] = 'N&atilde;o Testado';
$lang['owner'] = 'Permiss&atilde;o';
$lang['permissions'] = 'Permiss&otilde;es';
$lang['off'] = 'Off ';
$lang['on'] = 'On ';
$lang['permission_information'] = 'Informa&ccedil;&atilde;o Permiss&atilde;o ';
$lang['server_os'] = 'Sistema Operativo do Servidor';
$lang['server_api'] = 'API do Servidor';
$lang['server_software'] = 'Servidor Software';
$lang['server_information'] = 'Informa&ccedil;&atilde;o Servidor';
$lang['session_save_path'] = 'Caminho das Sess&otilde;es';
$lang['max_execution_time'] = 'Tempo M&aacute;ximo de Execu&ccedil;&atilde;o';
$lang['gd_version'] = 'GD vers&atilde;o';
$lang['upload_max_filesize'] = 'Tamanho M&aacute;ximo de Carregamento';
$lang['post_max_size'] = 'Tamanho M&aacute;ximo de Envio (Maximum Post Size)';
$lang['memory_limit'] = 'PHP Limite de Mem&oacute;ria';
$lang['server_db_type'] = 'Servidor  Base de Dados';
$lang['server_db_version'] = 'Servidor  Base de Dados Vers&atilde;o';
$lang['phpversion'] = 'Actual PHP Vers&atilde;o';
$lang['safe_mode'] = 'PHP Modo Seguro (Safe Mode)';
$lang['php_information'] = 'PHP Informa&ccedil;&atilde;o';
$lang['cms_install_information'] = 'CMS Informa&ccedil;&atilde;o de Instala&ccedil;&atilde;o';
$lang['cms_version'] = 'CMS Vers&atilde;o';
$lang['systeminfo_copy_paste'] = 'Por favor, copie e cole o texto selecionado no f&oacute;rum ';
$lang['help_systeminformation'] = 'As informa&ccedil;&otilde;es indicadas a seguir s&atilde;o recolhidas a partir de uma variedade de locais, e aqui resumidos de modo que possa ser capaz de encontrar convenientemente algumas das informa&ccedil;&otilde;es necess&aacute;rias por forma a tentar diagnosticar um problema ou pedir ajuda com a sua instala&ccedil;&atilde;o do CMS Made Simple.';
$lang['systeminfo'] = 'Informa&ccedil;&atilde;o do Sistema';
$lang['systeminfodescription'] = 'Mostrar v&aacute;rias informa&ccedil;&otilde;es sobre o seu sistema que poder&aacute; ser &uacute;til no diagn&oacute;stico de problemas';
$lang['error'] = 'Erro';
$lang['new_version_available'] = '<b>Aviso:</b> Uma nova vers&atilde;o do CMS est&aacute; dispon&iacute;vel. Por favor, notifique o administrador.';
$lang['info_urlcheckversion'] = 'Se a url &eacute; tem a palavra &quot;nenhum&quot; as verifica&ccedil;&otilde;es n&atilde;o ser&atilde;o feitas. <br />  O campo vazio ir&aacute; usar a URL padr&atilde;o.';
$lang['urlcheckversion'] = 'Verifique se h&aacute; novas vers&otilde;es do CMS usando esse URL';
$lang['read'] = 'Ler';
$lang['write'] = 'escrever';
$lang['execute'] = 'Executar';
$lang['group'] = 'Grupo';
$lang['other'] = 'Outro';
$lang['global_umask'] = 'Cria&ccedil;&atilde;o de Ficheiros Mask (umask)';
$lang['errorcantcreatefile'] = 'N&atilde;o foi poss&iacute;vel criar um arquivo (problema de permiss&otilde;es!)';
$lang['add'] = 'Adicionar';
$lang['about'] = 'Sobre';
$lang['action'] = 'Ac&ccedil;&atilde;o';
$lang['actionstatus'] = 'Ac&ccedil;&atilde;o/Estado';
$lang['active'] = 'Activo';
$lang['cantremove'] = 'Imposs&iacute;vel Remover';
$lang['changepermissions'] = 'Alterar Permiss&otilde;es';
$lang['changepermissionsconfirm'] = 'USAR COM PRECAU&Ccedil;&Atilde;O\n\nEste ac&ccedil;&atilde;o ir&aacute; tentar garantir que todos os arquivos que comp&otilde;em o m&oacute;dulo est&aacute; escrito pelo servidor da web.\nTem  a certeza que pretende continuar?';
$lang['success'] = 'Sucesso';
$lang['advanced'] = 'Avan&ccedil;ado';
$lang['back'] = 'Voltar ao Menu';
$lang['cancel'] = 'Cancelar';
$lang['cantchmodfiles'] = 'N&atilde;o foi poss&iacute;vel mudar permiss&otilde;es em alguns arquivos';
$lang['cantremovefiles'] = 'Problema remo&ccedil;&atilde;o de arquivos (permiss&otilde;es!)';
$lang['create'] = 'Criar';
$lang['database'] = 'Base de Dados';
$lang['databaseprefix'] = 'Base de Dados Prefixo';
$lang['databasetype'] = 'Base de Dados Tipo';
$lang['date'] = 'Data';
$lang['default'] = 'Padr&atilde;o';
$lang['delete'] = 'Eliminar';
$lang['deleteconfirm'] = 'Tem a certeza que pertende eliminar - %s - ?';
$lang['description'] = 'Descri&ccedil;&atilde;o';
$lang['directoryexists'] = 'Esta pasta j&aacute; existe.';
$lang['down'] = 'Baixo';
$lang['edit'] = 'Editar';
$lang['email'] = 'Endere&ccedil;o de Email';
$lang['errordeletingfile'] = 'Problema remo&ccedil;&atilde;o de arquivos. Problemas de permiss&otilde;es!';
$lang['errordirectorynotwritable'] = 'Sem permiss&atilde;o para escrever no direct&oacute;rio. Isto pode ser causado pelo arquivo permiss&otilde;es e propriedades. Modo seguro podem tamb&eacute;m estar activo.';
$lang['cachenotwritable'] = 'A Pasta do Cache n&atilde;o tem permiss&otilde;es de escrita. A limpeza do cache n&atilde;o ir&aacute; funcionar. Por favor fa&ccedil;a com que a tmp/cache tenha todas as permiss&otilde;es (chmod 777). Tamb&eacute;m pode ter que desactivar o modo seguro.';
$lang['modulesnotwritable'] = 'A Pasta dos m&oacute;dulos n&atilde;o tem permiss&otilde;es de escrita, se quiser instalar m&oacute;dulos fazendo o upload de um arquivo XML dever&aacute; fazer com que a pasta m&oacute;dulos tenha todas as permiss&otilde;es (chmod 777). Tamb&eacute;m pode ter que desactivar o modo seguro.';
$lang['false'] = 'Falso';
$lang['settrue'] = 'Defenir Verdadeiro';
$lang['filename'] = 'Nome do Arquivo';
$lang['filesize'] = 'Tamanho do Arquivo';
$lang['help'] = 'Ajuda';
$lang['language'] = 'Linguagem';
$lang['lastname'] = '&Uacute;ltimo Nome';
$lang['name'] = 'Nome';
$lang['password'] = 'Palavra Chave';
$lang['passwordagain'] = 'Palavra Chave (novamente)';
$lang['remove'] = 'Remover';
$lang['saveconfig'] = 'Salvar Configura&ccedil;&atilde;o';
$lang['true'] = 'Verdadeiro';
$lang['setfalse'] = 'Definir Falso';
$lang['type'] = 'Tipo';
$lang['typenotvalid'] = 'Tipo n&atilde;o &eacute; v&aacute;lido';
$lang['unknown'] = 'Desconhecido';
$lang['user'] = 'Utilizador';
$lang['userdefinedtags'] = 'Tags Personalizadas';
$lang['usermanagement'] = 'Gestor de Utilizadores';
$lang['username'] = 'Nome de utilizador';
$lang['usernameincorrect'] = 'Nome de utilizador ou palavra chave incorrecta';
$lang['version'] = 'Vers&atilde;o';
$lang['install_title'] = 'CMS Made Simple Instala&ccedil;&atilde;o (passo %s)';
$lang['install_system'] = 'Instala&ccedil;&atilde;o do Sistema';
$lang['install_thanks'] = 'Obrigado por instalar o CMS Made Simple';
$lang['upgrade_title'] = 'CMS Made Simple Upgrade (step %s)';
$lang['upgrade_system'] = 'Upgrade System';
$lang['upgrade_thanks'] = 'Thanks for upgrading CMS Made Simple to';
$lang['install_please_read'] = 'Por Favor leia  <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Problemas na Instala&ccedil;&atilde;o</a> na p&aacute;gina em  CMS Made Simple Documenta&ccedil;&atilde;o Wiki. ';
$lang['install_checking'] = 'Verifica&ccedil;&atilde;o das permiss&otilde;es e configura&ccedil;&otilde;es do PHP';
$lang['install_test'] = 'Teste';
$lang['install_result'] = 'Resultados';
$lang['install_required_settings'] = 'Configura&ccedil;&otilde;es Obrigat&oacute;rias';
$lang['install_recommended_settings'] = 'Configura&ccedil;&otilde;es Recomendadas';
$lang['install_you_have'] = 'Actual';
$lang['install_legend'] = 'Legenda';
$lang['install_symbol'] = 'Simbolo';
$lang['install_definition'] = 'Defini&ccedil;&atilde;o';
$lang['install_value_passed'] = 'Um test obrigat&oacute;rio passou';
$lang['install_value_failed'] = 'Um test obrigat&oacute;rio falhou';
$lang['install_error_fragment'] = 'Info Installation Troubleshooting';
$lang['install_value_required'] = 'A defini&ccedil;&atilde;o est&aacute; abaixo de um valor m&iacute;nimo exigido';
$lang['install_value_recommended'] = 'A defini&ccedil;&atilde;o est&aacute; acima do valor exigido, mas abaixo do valor recomendado <br /> ou ... A capacidade que <em> deveria </em> ser exigida para algumas funcionalidade opcionais n&atilde;o est&atilde;o dispon&iacute;veis';
$lang['install_value_exceed'] = 'A defini&ccedil;&atilde;o de atingir ou exceder o limite recomendado <br /> ou ... A capacidade que <em> deveria </ em> ser exigida para algumas funcionalidade opcionais est&atilde;o dispon&iacute;veis';
$lang['install_test_failed'] = 'Um ou mais testes falharam. Ainda pode instalar o sistema, mas algumas fun&ccedil;&otilde;es podem n&atilde;o funcionar correctamente. <br /> Por favor, tente corrigir a situa&ccedil;&atilde;o e clique em &quot;Tente novamente&quot;, ou clique no bot&atilde;o Continuar.';
$lang['install_test_passed'] = 'Todos os testes passaram (pelo menos no m&iacute;nimo recomendado). Por favor carregue no bot&atilde;o Continuar.';
$lang['install_failed_again'] = 'Um ou mais testes falharam. Corrija o problema e clique no bot&atilde;o abaixo para verificar novamente.';
$lang['install_try_again'] = 'Tente Novamente';
$lang['install_continue'] = 'Continuar';
$lang['failure'] = 'Falha';
$lang['caution'] = 'Cuidado';
$lang['install_admin_umask'] = 'Test de Cria&ccedil;&atilde;o de Arquivo Mask';
$lang['install_test_umask'] = 'Por Favor carregue neste bot&atilde;o para testar  . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .';
$lang['test_umask_text'] = 'umask (abrevia&ccedil;&atilde;o cria&ccedil;&atilde;o de arquivo do usu&aacute;rio em modo m&aacute;scara) &eacute; uma fun&ccedil;&atilde;o em ambientes POSIX que afecta o sistema de arquivos padr&atilde;o para a modalidade recentemente criada arquivos e direct&oacute;rios do actual processo. Ela controla quais as permiss&otilde;es de arquivo que n&atilde;o ser&aacute; definido para a rec&eacute;m-criado arquivo.';
$lang['test_check_umask'] = 'Resultados do teste na cria&ccedil;&atilde;o do ficheiro';
$lang['test_umask_not_given'] = 'Umask Vazio';
$lang['test_check_umask_failed'] = 'Teste umask falhou';
$lang['test_username_not_given'] = 'Nome de Utilizador Obrigat&oacute;rio!';
$lang['test_username_illegal'] = 'Nome de Utilizador cont&eacute;m caracteres inv&aacute;lidos!';
$lang['test_not_both_passwd'] = 'Ambas as Palavra chave s&atilde;o  obrigat&oacute;rias!';
$lang['test_passwd_not_match'] = 'Palavra chave n&atilde;o correspondem!';
$lang['test_email_accountinfo'] = 'Conta de E-mail seleccionada, mas n&atilde;o foi fornecido nenhum Email!';
$lang['test_database_prefix'] = 'Prefixo da Base de Dados cont&eacute;m caracteres inv&aacute;lidos';
$lang['test_no_dbms'] = 'N&atilde;o foi selecionado SGBD!';
$lang['test_could_not_connect_db'] = 'N&atilde;o foi poss&iacute;vel conectar ao banco de dados. Verifique se nome de usu&aacute;rio e senha est&atilde;o correctos, e que o usu&aacute;rio tem acesso a um determinado banco de dados.';
$lang['test_could_not_drop_table'] = 'N&atilde;o foi poss&iacute;vel remover uma tabela. Verifique se o usu&aacute;rio tem privil&eacute;gios para apagar as tabelas em determinado banco de dados.';
$lang['test_could_not_create_table'] = 'N&atilde;o foi poss&iacute;vel criar uma tabela. Verifique se o usu&aacute;rio tenha privil&eacute;gios para criar tabelas em um determinado banco de dados.';
$lang['test_check_php'] = 'A verificar a vers&atilde;o PHP %s+';
$lang['test_min_recommend'] = '(minimo %s, recomendado %s ou superior)';
$lang['test_min_recommend_plus'] = '(min %s, recomendado %s+)';
$lang['test_requires_php_version'] = 'CMS Made Simple requer uma vers&atilde;o do php 4.3 or superior (actual %s),  PHP %s ou superior &eacute; recomendado garanta a m&aacute;xima compatibilidade com a terceira parte addons';
$lang['test_check_md5_func'] = 'A verificar a Fun&ccedil;&atilde;o MD5';
$lang['test_check_safe_mode'] = 'A verificar o modo seguro';
$lang['test_check_safe_mode_failed'] = 'PHP modo seguro poder&aacute; criar alguns problemas com o carregamento de arquivos e outras fun&ccedil;&otilde;es. Tudo depende da forma rigorosa o seu servidor no modo seguro e suas configura&ccedil;&otilde;es.';
$lang['test_check_tokenizer'] = 'A verificar fun&ccedil;&otilde;es de tokenizer';
$lang['test_check_tokenizer_failed'] = 'N&atilde;o tendo o tokenizer poder&aacute; causar as p&aacute;ginas puramente brancas. &Eacute; exigido que tenha instalado.';
$lang['test_check_gd'] = 'A verificar a biblioteca GD';
$lang['test_check_gd_failed'] = 'A  biblioteca GD &eacute; obrigat&oacute;ria para alguns m&oacute;dulos e funcionalidades.';
$lang['test_check_write'] = 'A verificar as permiss&otilde;es de escrita';
$lang['test_may_not_exist'] = 'Este arquivo pode ainda n&atilde;o existir. Caso isso aconte&ccedil;a, deve criar um arquivo vazio com este nome. Tente tamb&eacute;m garantir que este arquivo tenha as permiss&otilde;es de escrita pelo servidor da Web.';
$lang['could_not_retrieve_a_value'] = 'N&atilde;o foi poss&iacute;vel obter um valor .... passa de qualquer maneira.';
$lang['displaying_the_value_originally'] = '<br />Verificando o valor inicialmente estabelecido no ficheiro de configura&ccedil;&atilde;o (isso pode n&atilde;o ser exacto).';
$lang['test_check_xml_func'] = 'A verificar pelo XML b&aacute;sico (expat) suporte';
$lang['test_allow_url_fopen_failed'] = 'Quando a permiss&atilde;o do url fopen estiver desactivado n&atilde;o poder&aacute; aceder &agrave; URL objecto como o arquivo que usa o protocolo http ou ftp.';
$lang['test_remote_url'] = 'Teste por URL remoto';
$lang['test_remote_url_failed'] = 'Provavelmente n&atilde;o ser&aacute; capaz de abrir um arquivo remoto em um servidor web.';
$lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
$lang['remote_connection_timeout'] = 'Connection Timed Out!';
$lang['search_string_find'] = 'Connection ok!';
$lang['connection_failed'] = 'Connection failed!';
$lang['remote_response_ok'] = 'Remote response: ok!';
$lang['remote_response_404'] = 'Remote response: not found!';
$lang['remote_response_error'] = 'Remote response: error!';
$lang['test_check_file_upload'] = 'A verificar o carregamento de arquivos';
$lang['test_check_file_failed'] = 'Quando o carregamento de arquivos est&aacute; desactivado n&atilde;o ser&aacute; capaz de utilizar qualquer uma das facilidades inclu&iacute;das no carregamento de arquivos do CMS Made Simple. Se poss&iacute;vel, esta restri&ccedil;&atilde;o deve ser levantada pelo seu sistema admin para utilizar correctamente todos os arquivos do sistema de gest&atilde;o de recursos. Prossiga com cuidado.';
$lang['test_check_memory'] = 'A verificar o PHP limite de mem&oacute;ria';
$lang['test_check_memory_failed'] = 'Pode n&atilde;o ter mem&oacute;ria suficiente para correr CMSMS correctamente, ou com todos os seus addons desejados. Se poss&iacute;vel, deve tentar obter no seu sistema mais memoria. Prossiga com cuidado.';
$lang['test_check_time_limit'] = 'A verificar PHP (time limit in second)';
$lang['test_check_time_limit_failed'] = 'N&uacute;mero de segundos permitido em um script. Se este for alcan&ccedil;ado, o script retorna um erro fatal.';
$lang['test_check_post_max'] = 'A verificar o (max post size)';
$lang['test_check_post_max_failed'] = 'Provavelmente n&atilde;o ser&aacute; capaz de submeter (grandes) dados. Lembre-se desta restri&ccedil;&atilde;o.';
$lang['test_check_upload_max'] = 'A verificar (max upload file size)';
$lang['test_check_upload_max_failed'] = 'Provavelmente n&atilde;o ser&aacute; capaz de carregar (grandes) arquivos. Lembre-se desta restri&ccedil;&atilde;o.';
$lang['test_check_writable'] = 'A verificar se %s tem permis&atilde;o de escrita';
$lang['test_check_upload_failed'] = 'A pasta Uploads n&atilde;o tem permiss&otilde;es de escrita. Ainda pode instalar o sistema, mas n&atilde;o ser&aacute; capaz de de carregar arquivos atrav&eacute;s do painel de administra&ccedil;&atilde;o.';
$lang['test_check_images_failed'] = 'A pasta Images n&atilde;o tem permiss&otilde;es de escrita. Ainda pode instalar o sistema, mas n&atilde;o ser&aacute; capaz de de carregar arquivos atrav&eacute;s do painel de administra&ccedil;&atilde;o.';
$lang['test_check_modules_failed'] = 'A pasta modules n&atilde;o tem permiss&otilde;es de escrita. Ainda pode instalar o sistema, mas n&atilde;o ser&aacute; capaz de de carregar arquivos atrav&eacute;s do painel de administra&ccedil;&atilde;o.';
$lang['test_check_file_get_contents'] = 'A verificar por (file_get_contents)';
$lang['test_check_file_get_contents_failed'] = 'Provavelmente n&atilde;o ser&aacute; capaz de utilizar qualquer uma das funcionalidades que utiliza esta fun&ccedil;&atilde;o';
$lang['test_check_session_save_path'] = 'A verificar se (session.save_path) tem permis&atilde;o de escrita';
$lang['test_empty_session_save_path'] = 'O seu session.save_path est&aacute; vazio. O PHP usar&aacute; o direct&oacute;rio tempor&aacute;rio do seu sistema operacional. Se tem problemas SESSION ini_set  pode tentar activar cookies acrescentando: ini_set ( &quot;session.use_only_cookies&quot;, 1); ao topo de include.php';
$lang['test_check_session_save_path_failed'] = 'O seu session.save_path &eacute; &quot;% s&quot;. N&atilde;o tendo esta como escrita n&atilde;o pode fazer logins do painel de administra&ccedil;&atilde;o.  Este teste pode falhar se safe_mode est&aacute; activado (veja abaixo).';
$lang['test_check_ini_set'] = 'A verificar se ini_set trabalha correctamente';
$lang['test_check_ini_set_failed'] = 'Embora a capacidade de substituir o php ini n&atilde;o &eacute; obrigat&oacute;ria, alguns addon (opcional) utilizam ini_set timeouts de extens&atilde;o, e permite o upload de arquivos maiores, etc Pode ter dificuldade com algumas funcionalidades nos addon sem esta capacidade. Este teste pode falhar se o safe_mode estiver activo (veja abaixo).';
$lang['install_admin_header'] = 'Informa&ccedil;&atilde;o de Conta para o Administrador';
$lang['install_admin_info'] = 'Seleccione o nome de utilizador, senha e endere&ccedil;o de e-mail para sua conta de administrador. Por favor, certifique-se de gurdar esta senha em algum lugar, n&atilde;o haver&aacute; outra maneira de entrar em sua administra&ccedil;&atilde;o do CMS Made Simple sem ela.';
$lang['install_admin_email'] = 'Endere&ccedil;o de E-mail';
$lang['install_admin_email_info'] = 'Informa&ccedil;&atilde;o de Conta para o E-mail';
$lang['install_admin_email_note'] = '<strong>Nota:</strong> Essa fun&ccedil;&atilde;o usa a fun&ccedil;&atilde;o mail do php. Se n&atilde;o receber este e-mail, pode ser uma indica&ccedil;&atilde;o de que o seu servidor n&atilde;o est&aacute; correctamente configurado e que deve entrar em contacto com seu administrador de alojamento.';
$lang['install_admin_sitename'] = 'Este &eacute; o nome do seu site. Vai ser utilizados em v&aacute;rios locais dos modelos padr&atilde;o e pode ser usado em qualquer lugar com a	{sitename} tag.';
$lang['install_admin_db'] = 'Base de Dados Informa&ccedil;&atilde;o';
$lang['install_admin_db_info'] = '<p>Certifique-se de ter criado a sua base de dados e os privil&eacute;gios a um utilizador para usar essa base de dados.</p>
<p>Para MySQL, use o seguinte:</p>
<p>Acesse a mysql a partir de um consola e execute os seguintes comandos:</p>
<ol>
<li>create database cms; (use qualquer nome que quer aqui, mas certifique-se de gurdar-lo, ser&aacute; necess&aacute;rio inseri-lo nesta p&aacute;gina)</li>
<li>grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;;</li>
</ol>';
$lang['install_admin_follow'] = 'Preencha os campos a seguir';
$lang['install_admin_db_type'] = 'Base de Dados Tipo';
$lang['install_admin_no_db'] = 'Drivers da Base de Dados inv&aacute;lidos. Por favor, confirme que voc&ecirc; tem o MySQL, mysqli, e / ou apoio postgres7 instalado, e tente novamente.';
$lang['install_admin_db_host'] = 'Base de Dados host ';
$lang['install_admin_db_name'] = 'Nome da Base de Dados';
$lang['install_admin_db_create'] = 'Cria&ccedil;&atilde;o Tabelas (Aviso: elimina a existente)';
$lang['install_admin_db_prefix'] = 'Tabela prefixo';
$lang['install_admin_db_sample'] = 'Instalar conte&uacute;do b&aacute;sico e temas';
$lang['retry'] = 'Repetir';
$lang['install_admin_db_create_seq'] = 'Cria&ccedil;&atilde;o %s tabela sequ&ecirc;ncia...';
$lang['install_admin_importing'] = 'Importar dados b&aacute;sicos...';
$lang['invalid_query'] = 'Consulta inv&aacute;lida: %s';
$lang['install_creating_table'] = '<p>Cria&ccedil;&atilde;o %s tabela... [%s]</p>';
$lang['install_creating_index'] = '<p>Cria&ccedil;&atilde;o index em %s tabela... [%s]</p>';
$lang['done'] = 'processado';
$lang['failed'] = 'falhou';
$lang['install_admin_error_schema'] = 'Erro na recupera&ccedil;&atilde;o do esquema SQL';
$lang['install_admin_set_account'] = 'Defini&ccedil;&otilde;es  informa&ccedil;&atilde;o da conta de administra&ccedil;&atilde;o...';
$lang['install_admin_set_sitename'] = 'Defini&ccedil;&atilde;o nome do site...';
$lang['install_admin_setup'] = 'Agora vamos continuar a configura&ccedil;&atilde;o do seu arquivo de configura&ccedil;&atilde;o, j&aacute; temos a maior parte das coisas que precisamos. Provavelmente, pode deixar todos estes valores por si s&oacute;, assim quando estiver pronto, clique em Continuar.';
$lang['install_admin_docroot'] = 'CMS Documento root (como pode ser visto a partir do servidor web)';
$lang['install_admin_docroot_path'] = 'Caminho para o documento root';
$lang['install_admin_querystring'] = 'Query string (deixe sozinha a menos que tenha problemas, em seguida, edite o config.php a manualmente)';
$lang['invalid_querys'] = '<b>AVISO<b/>: Busca inv&aacute;lida na sua base de dados!';
$lang['install_admin_sitedown'] = 'Erro: N&atilde;o removeu o arquivo:  tmp/cache/SITEDOWN por favor remova manualmente.';
$lang['install_admin_update_hierarchy'] = 'Actualizar a posi&ccedil;&atilde;o de  hierarquia...';
$lang['install_admin_set_core_event'] = 'A Configurar os eventos...';
$lang['install_admin_install_modules'] = 'M&oacute;dulos Instalados...';
$lang['install_admin_index_search'] = 'Indexar Pesquisa...';
$lang['install_admin_clear_cache'] = 'Limpar o cache do site (se tiver algum cache)...';
$lang['install_admin_emailing'] = 'E-mailing informa&ccedil;&atilde;o da conta de administra&ccedil;&atilde;o...';
$lang['install_admin_congratulations'] = 'Parab&eacute;ns, configurou todo o sistema - visite o seu novo ';
$lang['could_not_connect_db'] = 'N&atilde;o foi poss&iacute;vel conectar ao banco de dados. Verifique se nome de usu&aacute;rio e senha est&atilde;o correctos, e que o usu&aacute;rio tenha acesso a um determinado banco de dados.';
$lang['cannot_write_config'] = 'Erro:  N&atilde;o &eacute; poss&iacute;vel escrever em %s.';
$lang['email_accountinfo_subject'] = 'CMS Made Simple informa&ccedil;&atilde;o da conta de administra&ccedil;&atilde;o';
$lang['email_accountinfo_message'] = 'Obrigado por instalar o CMS.

A sua nova informa&ccedil;&atilde;o da conta:
Nome de Utilizador: %s
Palavra Chave: %s

Administra&ccedil;&atilde;o do site em: %s';
$lang['utma'] = '156861353.762059600.1340221806.1340221806.1340221806.1';
$lang['utmz'] = '156861353.1340221806.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/viewtopic.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>